@@ -66,7 +66,7 @@ class TestSections(unittest.TestCase):
         self.assertAlmostEqual(21_000, hole.get_bottom_depth(), 10)
 
         # test fetching of the correct casing at a given depth
-        casing1 = hole.find_section_at_measured_depth(10_000)
+        casing1 = hole.find_section_at_measured_depth(10_000, False)
         self.assertEqual(id(hole_section2), id(casing1))
 
         # testing unique boundary depths
@@ -116,7 +116,7 @@ class TestSections(unittest.TestCase):
         self.assertAlmostEqual(wits.get('data', {}).get('bit_depth'), drillstring[-1].bottom_depth, 10)
 
         # test for finding drillstring section at a measured depth
-        drillstring_section3 = drillstring.find_section_at_measured_depth(8_000)
+        drillstring_section3 = drillstring.find_section_at_measured_depth(8_000, False)
         self.assertAlmostEqual(3.83, drillstring_section3.inner_diameter, 1)
         self.assertAlmostEqual(4.5, drillstring_section3.outer_diameter, 10)
 
@@ -241,6 +241,46 @@ class TestSections(unittest.TestCase):
         wellbore = set_drillstring_and_create_wellbore(wits_record)
         self.assertIsNone(wellbore)
 
+    def test_riserless(self):
+        wits_json_file = os.path.abspath(
+            os.path.join(os.path.dirname(os.path.dirname(__file__)), "resources", "test", "wits_riserless.json")
+        )
+        wits = file_to_json(wits_json_file)
+        wellbore = set_drillstring_and_create_wellbore(wits)
+
+        hole: Hole = wellbore.actual_hole
+
+        self.assertEqual(2, len(hole))
+
+        self.assertEqual(HoleType.CASED_HOLE, hole[0].hole_type)
+        self.assertAlmostEqual(3000.0, hole[0].top_depth, 1)
+        self.assertAlmostEqual(10000.0, hole[0].bottom_depth, 1)
+        self.assertAlmostEqual(7000.0, hole[0].length, 1)
+        self.assertAlmostEqual(12.415, hole[0].inner_diameter, 0.01)
+
+        self.assertEqual(HoleType.OPEN_HOLE, hole[1].hole_type)
+        self.assertAlmostEqual(10_000.0, hole[1].top_depth, 1)
+        self.assertAlmostEqual(15000, hole[1].bottom_depth, 1)
+
+        drillstring = wellbore.actual_drillstring
+        self.assertAlmostEqual(0.0, drillstring[0].top_depth, 1)
+        self.assertAlmostEqual(15_000.0, drillstring[-1].bottom_depth, 1)
+
+        annulus = wellbore.actual_annulus
+        self.assertAlmostEqual(3_000.0, annulus[0].top_depth, 1)
+        self.assertAlmostEqual(10_000.0, annulus[0].bottom_depth, 1)
+        self.assertAlmostEqual(12.415, annulus[0].inner_diameter_hole, 0.01)
+        self.assertEqual(HoleType.CASED_HOLE, annulus[0].hole_type)
+
+        self.assertAlmostEqual(10_000.0, annulus[1].top_depth, 1)
+        self.assertAlmostEqual(14_895.9, annulus[1].bottom_depth, 1)
+        self.assertEqual(HoleType.OPEN_HOLE, annulus[1].hole_type)
+
+        self.assertAlmostEqual(14906.77, annulus[3].top_depth, 1)
+        self.assertAlmostEqual(15_000.0, annulus[3].bottom_depth, 1)
+        self.assertAlmostEqual(8.5, annulus[3].inner_diameter_hole, 0.01)
+        self.assertEqual(HoleType.OPEN_HOLE, annulus[3].hole_type)
+
 
 def get_wits():
     wits_json_file = os.path.abspath(
