@@ -1,5 +1,8 @@
 import json
 import time
+from typing import List
+
+from worker.app.modules import Module
 
 from worker.app.modules.time_activity_module import TimeActivityModule
 from worker.data.operations import gather_data_for_period
@@ -264,14 +267,17 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
         super().save_state(state_key=state_key, timestamp=timestamp, raise_warnings=raise_warnings)
 
-    def get_modules(self):
-        raise exceptions.Misconfigured("No modules found")
+    def get_modules(self) -> List[Module]:
+        raise NotImplementedError("No modules found")
+
+    def get_active_modules(self) -> List[Module]:
+        return [module for module in self.get_modules() if module.enabled]
 
     def run_modules(self):
         if not self.event:
             return
 
-        for module_type in self.get_modules():
+        for module_type in self.get_active_modules():
             try:
                 module = module_type(self.state, rollbar=self.rollbar)
             except Exception:
