@@ -397,13 +397,13 @@ def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
     raise TypeError("Event is not either a scheduler or kafka consumer")
 
 
-def compute_time_step(records: Union[List[WITS], List[float]], percent=50) -> Union[int, None]:
+def compute_time_step(records: Union[List[WITS], List[dict], List[float]], percent=50) -> Union[int, None]:
     """
     Compute the time step of the wits records
     If the intention is to split the data based on their activities a higher percent
     is recommended (such as 99%). For other cases 50% might work.
 
-    :param records: a list of WITS records
+    :param records: a list of wits records in WITS or dict format, or a list of timestamps
     :param percent: this is an important parameter to get the correct time step
     :return:
     """
@@ -415,9 +415,13 @@ def compute_time_step(records: Union[List[WITS], List[float]], percent=50) -> Un
 
     if isinstance(records[0], WITS):
         timestamps = [rec.timestamp for rec in records]
+    elif isinstance(records[0], dict):
+        timestamps = [rec.get('timestamp') for rec in records]
     else:
         timestamps = records
 
+    timestamps = [timestamp for timestamp in timestamps if is_finite(timestamp)]
+
     # a list of time steps for all the timestamps
     diffs = np.diff(timestamps)
 
