@@ -113,15 +113,6 @@ class Drillstring(SectionsMixin):
 
             self.add_section(component)
 
-    def find_section_at_measured_depth(self, measured_depth: float) -> Union[Pipe, None]:
-        """
-        This method returns the pipe at the given measured depth.
-        :return:
-        """
-        if measured_depth > self[-1].bottom_depth:
-            return None
-        return next((sec for sec in self if sec.top_depth < measured_depth <= sec.bottom_depth), self[0])
-
     def perform_qc(self, hole: Hole):
         """
         Removes the items that the pipe OD is equal to or greater than the bit/hole size or OD is equal to 0.
