@@ -26,7 +26,15 @@ class Hole(SectionsMixin):
         :param section:
         :return:
         """
-        section.top_depth = 0 if not self else self[-1].bottom_depth
+        if not self:
+            top_depth = section.top_depth
+
+            if top_depth < DEPTH_THRESHOLD:
+                section.top_depth = 0
+
+        if self:
+            section.top_depth = self[-1].bottom_depth
+
         # bottom depth is the source of truth, so we are updating the length
         section.set_length()
 
@@ -171,9 +179,6 @@ class Hole(SectionsMixin):
 
         self.update_depths()
 
-    def find_section_at_measured_depth(self, measured_depth: float) -> HoleSection:
-        return next((sec for sec in self if sec.top_depth < measured_depth <= sec.bottom_depth), self[0])
-
     def get_min_inner_diameter(self) -> Union[float, None]:
         if not self:
             return None
